# Contributing

All contributions via pull request are accepted. You can also open an issue if you find a bug, or have a suggestion.

If you open a pull request, please consider adding yourself to the list of contributors, using the template below. Please keep the alphabetic order.

```
* [mailto:john.doe@mail.ca](John Doe)
```
